function  [angle, phimax, thetamax]=Capon_spectrum(Y, P, c, fc, resol, runNumber)


% Y=[Y(1,:);Y(5,:);Y(2,:);Y(6,:);Y(3,:);Y(7,:);Y(4,:);Y(8,:)];

% Capon Spectrum beamforming
%******************************
%INPUT
%Y: Matrix of measurements of order 4m x n, where n: number of measurement
%and m: number of vector sensors. 
%P: Martrix with sensor positions of order 3 x m.
%c: Speed of sound.
%fc: central frequency of narrowband signal.
%
%NOTE:% Yj row corresponding to velocity measurements should be normalized by
% -pho*c
%
%OUTPUT
% 2D Capon Spectrum plot
%
%PHYSICAL ASSUMPTIONS
%
%A1: plane wave incomming the array.
%A2: narrow band sources.
%
%Patricio S. La Rosa and Arye Nehorai
%CSSIP, ESE Department, WUSTL
%April, 2009
%email: pla@ese.wustl.edu


% Scaling data
scale=-100*((10)^3)*340;

%System dimensions
[m1,n]=size(Y);                 % Number of measurements and samples
m=m1/4;                         % Number of vector sensors

Y=Y-mean(Y,2)*ones(1,n);

%Array sample covariance matrix
R= (Y*Y')/n;

%Eigenspectrum decomposition
% [V,L]=eig(R)
% ll=diag(L);
% [val,pos]=max(ll);
% Vsel=V(:,pos);
% R=ll(pos)*Vsel*Vsel';

%Vsel=V(:,3:4);
%Lsel=L(3:4,3:4);
%Reig=Vsel*Lsel*Vsel';

P=P-P;

%COMPUTING CAPON SPECTRA
%************************************
%theta=0:2*pi/resol:2*pi;%(theta)
%phi=-(pi/2):(pi/2)/resol:(pi/2);%(phi)
%[THETA,PHI]=meshgrid(theta, phi);


[X1,Y1,Z1]=sphere(resol);
[THETA,PHI,Radio] = cart2sph(X1,Y1,Z1);

[T1,T2]=size(PHI);
ak=cell(T1,T2);
hk=cell(T1,T2);
uk=cell(T1,T2);
f=zeros(T1,T2);


for l=1:T1;
    for i=1:T2
        
        %Directional vector for source k
        uk{l,i} = [cos(THETA(l,i))*cos(PHI(l,i));sin(THETA(l,i))*cos(PHI(l,i));sin(PHI(l,i))];
        
        %Directional response vector for source k
        hk{l,i}=[1;uk{l,i}];
        
        %Phase information delay vector
        delayk = - P'*uk{l,i}/c;
        ap= exp(-j*2*pi*fc*delayk);   
        
        %Array steering vector
        ak{l,i}=kron(ap,hk{l,i});
        
        %Capon Spectra as a function of azimuth and elevation
        f(l,i)= ((ak{l,i})'*inv(R)*ak{l,i})^(-1);
        
    end
end


%Changing from spherical to cartesian coordinates
%[Xm,Ym,Zm]=sph2cart(PHI,PSI,abs(f));
%surf(Xm,Ym,Zm,abs(f));


% Finding the maximum
%**********************
[C,rowcs]=max(abs(f));
[D,cold]=max(C);
rowc=rowcs(cold);

xmax=X1(rowc,cold);
ymax=Y1(rowc,cold);
zmax=Z1(rowc,cold);
phimax=PHI(rowc,cold)*180/pi;
thetamax=THETA(rowc,cold)*180/pi;
angle=thetamax;

Pointmax=[xmax;ymax;zmax];


figure(1)
%figure(runNumber*2-1)

subplot(2,2,runNumber*2-1),surf(X1,Y1,Z1,abs(f));
colormap('jet')
colorbar
xlabel('x')
ylabel('y')
zlabel('z')
title(['\phi = ', num2str(phimax),' \theta = ',num2str(thetamax)])
view(107,40)
hold on
global tcolor
tcolor=[1; 0; 0];
arrow(zeros(3,1),1.8*Pointmax)
hold on
%ploting coordinates axis

tcolor=[0; 0; 0];
arrow(zeros(3,1),2*[1;0;0]);
hold on
arrow(zeros(3,1),2*[0;1;0]);
hold on
arrow(zeros(3,1),2*[0;0;1]);

%arrow fixlimits
hold off
%camzoom(1.3);
%light; lighting phong; 
%view(3)
%figure(runNumber*2)
subplot(2,2,runNumber*2), pcolor(PHI*180/pi,THETA*180/pi,abs(f));
xlabel('\phi')
ylabel('\psi')
